NAME

Application default credentials.

Google::Auth - Implements application default credentials and project ID detection.

VERSION

Version 0.07

SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

use Google::Auth;

my $gauth = Google::Auth->new();
...

EXPORT

A list of functions that can be exported. You can delete this section if you don't export anything, such as for a purely object-oriented module.

SUBROUTINES/METHODS

default( $scopes, $options )

Gets the default credentials for the current environment.

CONFIGURATION AND ENVIRONMENT

GOOGLE_EXTERNAL_ACCOUNT_ALLOW_EXECUTABLES

Set to '1' to allow Pluggable Credentials to execute external commands. Default is '0' (disabled).

GOOGLE_EXTERNAL_ACCOUNT_ALLOW_CUSTOM_UNIVERSES

Set to '1' to allow custom universes in credentials files loaded from JSON. Default is '0' (disabled).

AUTHOR

C.J. Collier, <cjac at google.com>

BUGS AND SUPPORT

Please report any bugs or feature requests to the GitHub issue tracker at https://github.com/GoogleCloudPlatform/google-auth-library-perl/issues or via RT at https://rt.cpan.org/Dist/Display.html?Name=Google-Auth.

You can also look for information at:

ACKNOWLEDGEMENTS

LICENSE AND COPYRIGHT

Copyright 2020 Google LLC and contributors

This program is released under the following license: Apache 2.0